@@ -55,23 +55,13 @@ FormatFactory *FormatFactory::Private::sSelf = 0;
 
 KLibrary *FormatFactory::Private::openLibrary( const QString &libName )
 {
-  KLibrary *library = 0;
-
-  QString path = KLibLoader::findLibrary( libName );
-
-  if ( path.isEmpty() ) {
-    kDebug( 5700 ) << "No format plugin library was found!";
-    return 0;
+  KLibrary *library = new KLibrary( libName );
+  if (library->load()) {
+    return library;
   }
-
-  library = KLibLoader::self()->library( path );
-
-  if ( !library ) {
-    kDebug( 5700 ) << "Could not load library '" << libName << "'";
-    return 0;
-  }
-
-  return library;
+  kDebug(5700) << library->errorString();
+  delete library;
+  return 0;
 }
 
 FormatFactory *FormatFactory::self()
@@ -101,7 +91,7 @@ FormatFactory::FormatFactory()
                                        KStandardDirs::Recursive |
                                        KStandardDirs::NoDuplicates );
   for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
-    KConfig config( *it, KConfig::OnlyLocal );
+    KConfig config( *it, KConfig::SimpleConfig );
 
     if ( !config.hasGroup( "Misc" ) || !config.hasGroup( "Plugin" ) ) {
       continue;
@@ -187,7 +177,7 @@ Format *FormatFactory::format( const QString &type )
     format->setNameLabel( fi.nameLabel );
     format->setDescriptionLabel( fi.descriptionLabel );
   } else {
-    kDebug( 5700 ) << "'" << libName << "' is not a format plugin.";
+    kDebug(5700) << "'" << libName << "' is not a format plugin.";
     return 0;
   }
 
