@@ -19,20 +19,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <sys/types.h>
-#include <iostream>
-#include <unistd.h>
-
-#define QT3_SUPPORT
-#include <q3listview.h>
-
-#include <QWidget>
-#include <QLabel>
-#include <QLayout>
-#include <QPushButton>
-#include <QDir>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
+#include "testlock.h"
+#include "kabc/stdaddressbook.h"
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -43,9 +31,18 @@
 #include <kmessagebox.h>
 #include <kdialog.h>
 
-#include "kabc/stdaddressbook.h"
+#include <qtreewidget.h>
+#include <QtGui/QWidget>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPushButton>
+#include <QtCore/QDir>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QHBoxLayout>
 
-#include "testlock.h"
+#include <sys/types.h>
+#include <iostream>
+#include <unistd.h>
 
 using namespace KABC;
 
@@ -67,7 +64,7 @@ LockWidget::LockWidget( const QString &identifier )
     topLayout->addWidget( pidLabel );
 
     QHBoxLayout *identifierLayout = new QHBoxLayout();
-	identifierLayout->setParent( topLayout );
+    identifierLayout->setParent( topLayout );
     topLayout->addItem( identifierLayout );
 
     QLabel *resourceLabel = new QLabel( "Identifier:", this );
@@ -88,11 +85,13 @@ LockWidget::LockWidget( const QString &identifier )
     connect( button, SIGNAL( clicked() ), SLOT( unlock() ) );
   }
 
-  mLockView = new Q3ListView( this );
+  mLockView = new QTreeWidget( this );
   topLayout->addWidget( mLockView );
-  mLockView->addColumn( "Lock File" );
-  mLockView->addColumn( "PID" );
-  mLockView->addColumn( "Locking App" );
+  QStringList headers;
+  headers.append( "Lock File" );
+  headers.append( "PID" );
+  headers.append( "Locking App" );
+  mLockView->setHeaderLabels( headers );
 
   updateLockView();
 
@@ -125,15 +124,21 @@ void LockWidget::updateLockView()
   QStringList files = dir.entryList( QStringList( "*.lock" ) );
 
   QStringList::ConstIterator it;
-  for( it = files.begin(); it != files.end(); ++it ) {
-    if ( *it == "." || *it == ".." ) continue;
+  for ( it = files.begin(); it != files.end(); ++it ) {
+    if ( *it == "." || *it == ".." ) {
+      continue;
+    }
 
     QString app;
     int pid;
     if ( !Lock::readLockFile( dir.filePath( *it ), pid, app ) ) {
-      kWarning() << "Unable to open lock file '" << *it << "'" << endl;
+      kWarning() << "Unable to open lock file '" << *it << "'";
     } else {
-      new Q3ListViewItem( mLockView, *it, QString::number( pid ), app );
+      QTreeWidgetItem *item = new QTreeWidgetItem();
+      item->setText( 0, *it );
+      item->setText( 1, QString::number( pid ) );
+      item->setText( 2, app );
+      mLockView->addTopLevelItem( item );
     }
   }
 }
@@ -156,21 +161,17 @@ void LockWidget::unlock()
   }
 }
 
-
-static const KCmdLineOptions options[] =
+int main( int argc, char **argv )
 {
-  { "a", 0, 0 },
-  { "addressbook", "Standard address book", 0 },
-  { "d", 0, 0 },
-  { "diraddressbook", "Standard address book directory resource", 0 },
-  { "+identifier", "Identifier of resource to be locked, e.g. filename", 0 },
-  KCmdLineLastOption
-};
+  KAboutData aboutData( "testlock", 0, ki18n( "Test libkabc Lock" ), "0.1" );
+  KCmdLineArgs::init( argc, argv, &aboutData );
 
-int main(int argc,char **argv)
-{
-  KAboutData aboutData("testlock",I18N_NOOP("Test libkabc Lock"),"0.1");
-  KCmdLineArgs::init(argc,argv,&aboutData);
+  KCmdLineOptions options;
+  options.add("a");
+  options.add("addressbook", ki18n("Standard address book"));
+  options.add("d");
+  options.add("diraddressbook", ki18n("Standard address book directory resource"));
+  options.add("+identifier", ki18n("Identifier of resource to be locked, e.g. filename"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KApplication app;
