@@ -45,43 +45,50 @@ using namespace KBlog;
 GData::GData( const KUrl &server, QObject *parent )
   : Blog( server, *new GDataPrivate, parent )
 {
+  kDebug(5323);
   setUrl( server );
 }
 
 GData::~GData()
 {
+  kDebug(5323);
 }
 
 QString GData::interfaceName() const
 {
+  kDebug(5323);
   return QLatin1String( "Google Blogger Data" );
 }
 
 QString GData::fullName() const
 {
+  kDebug(5323);
   return d_func()->mFullName;
 }
 
 void GData::setFullName( const QString &fullName )
 {
+  kDebug(5323);
   Q_D( GData );
   d->mFullName = fullName;
 }
 
 QString GData::profileId() const
 {
+  kDebug(5323);
   return d_func()->mProfileId;
 }
 
 void GData::setProfileId( const QString &pid )
 {
+  kDebug(5323);
   Q_D( GData );
   d->mProfileId = pid;
 }
 
 void GData::fetchProfileId()
 {
-  kDebug() << "fetchProfileId()";
+  kDebug(5323);
   QByteArray data;
   KIO::Job *job = KIO::get( url(), KIO::NoReload, KIO::HideProgressInfo );
   KUrl blogUrl = url();
@@ -93,7 +100,7 @@ void GData::fetchProfileId()
 
 void GData::listBlogs()
 {
-  kDebug();
+  kDebug(5323);
   Syndication::Loader *loader = Syndication::Loader::create();
   connect( loader,
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
@@ -106,6 +113,7 @@ void GData::listRecentPosts( const QStringList &labels, int number,
                              const KDateTime &upMinTime, const KDateTime &upMaxTime,
                              const KDateTime &pubMinTime, const KDateTime &pubMaxTime )
 {
+  kDebug(5323);
   Q_D( GData );
   QString urlString( "http://www.blogger.com/feeds/" + blogId() + "/posts/default" );
   if ( ! labels.empty() ) {
@@ -143,13 +151,14 @@ void GData::listRecentPosts( const QStringList &labels, int number,
 
 void GData::listRecentPosts( int number )
 {
+  kDebug(5323);
   listRecentPosts( QStringList(), number );
 }
 
 void GData::listComments( KBlog::BlogPost *post )
 {
+  kDebug(5323);
   Q_D( GData );
-  kDebug() << "listComments()";
   Syndication::Loader *loader = Syndication::Loader::create();
   d->mListCommentsMap[ loader ] = post;
   connect( loader,
@@ -162,7 +171,7 @@ void GData::listComments( KBlog::BlogPost *post )
 
 void GData::listAllComments()
 {
-  kDebug();
+  kDebug(5323);
   Syndication::Loader *loader = Syndication::Loader::create();
   connect( loader,
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
@@ -173,6 +182,7 @@ void GData::listAllComments()
 
 void GData::fetchPost( KBlog::BlogPost *post )
 {
+  kDebug(5323);
   Q_D( GData );
 
   if ( !post ) {
@@ -192,8 +202,8 @@ void GData::fetchPost( KBlog::BlogPost *post )
 
 void GData::modifyPost( KBlog::BlogPost *post )
 {
+  kDebug(5323);
   Q_D( GData );
-  kDebug();
 
   if ( !post ) {
     kError(5323) << "post is null pointer";
@@ -254,8 +264,8 @@ void GData::modifyPost( KBlog::BlogPost *post )
 
 void GData::createPost( KBlog::BlogPost *post )
 {
+  kDebug(5323);
   Q_D( GData );
-  kDebug();
 
   if ( !post ) {
     kError(5323) << "post is null pointer";
@@ -315,8 +325,8 @@ void GData::createPost( KBlog::BlogPost *post )
 
 void GData::removePost( KBlog::BlogPost *post )
 {
+  kDebug(5323);
   Q_D( GData );
-  kDebug();
 
   if ( !post ) {
     kError(5323) << "post is null pointer";
@@ -412,6 +422,7 @@ void GData::createComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
 
 void GData::removeComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
 {
+  kDebug(5323);
   Q_D( GData );
   kDebug();
 
@@ -459,14 +470,17 @@ void GData::removeComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
 
 GDataPrivate::GDataPrivate():mAuthenticationString(), mAuthenticationTime()
 {
+  kDebug(5323);
 }
 
 GDataPrivate::~GDataPrivate()
 {
+  kDebug(5323);
 }
 
 bool GDataPrivate::authenticate()
 {
+  kDebug(5323);
   Q_Q( GData );
   QByteArray data;
   KUrl authGateway( "https://www.google.com/accounts/ClientLogin" );
@@ -497,6 +511,11 @@ bool GDataPrivate::authenticate()
 
 void GDataPrivate::slotFetchProfileIdData( KIO::Job *job, const QByteArray &data )
 {
+  kDebug(5323);
+  if( !job ){
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mFetchProfileIdBuffer[ job ].size();
   mFetchProfileIdBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mFetchProfileIdBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -504,6 +523,11 @@ void GDataPrivate::slotFetchProfileIdData( KIO::Job *job, const QByteArray &data
 
 void GDataPrivate::slotFetchProfileId( KJob *job )
 {
+  kDebug(5323);
+  if( !job ){
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   Q_Q( GData );
   if ( !job->error() ) {
     QRegExp pid( "http://www.blogger.com/profile/(\\d+)" );
@@ -529,8 +553,12 @@ void GDataPrivate::slotFetchProfileId( KJob *job )
 void GDataPrivate::slotListBlogs( Syndication::Loader *loader,
                                   Syndication::FeedPtr feed,
                                   Syndication::ErrorCode status ) {
+  kDebug(5323);
   Q_Q( GData );
-  Q_UNUSED( loader );
+  if( !loader ) {
+    kError(5323) << "loader is a null pointer.";
+    return;
+  }
   if ( status != Syndication::Success ) {
     emit q->error( GData::Atom, i18n( "Could not get blogs." ) );
     return;
@@ -564,7 +592,12 @@ void GDataPrivate::slotListComments( Syndication::Loader *loader,
                                      Syndication::FeedPtr feed,
                                      Syndication::ErrorCode status )
 {
+  kDebug(5323);
   Q_Q( GData );
+  if( !loader ) {
+    kError(5323) << "loader is a null pointer.";
+    return;
+  }
   BlogPost *post = mListCommentsMap[ loader ];
   mListCommentsMap.remove( loader );
 
@@ -599,7 +632,7 @@ void GDataPrivate::slotListComments( Syndication::Loader *loader,
                  KDateTime::Spec::UTC() ) );
     commentList.append( comment );
   }
-  kDebug(5323) << "Emitting listedRecentPosts()";
+  kDebug(5323) << "Emitting listedComments()";
   emit q->listedComments( post, commentList );
 }
 
@@ -607,8 +640,12 @@ void GDataPrivate::slotListAllComments( Syndication::Loader *loader,
                                         Syndication::FeedPtr feed,
                                         Syndication::ErrorCode status )
 {
+  kDebug(5323);
   Q_Q( GData );
-  Q_UNUSED( loader );
+  if( !loader ) {
+    kError(5323) << "loader is a null pointer.";
+    return;
+  }
 
   if ( status != Syndication::Success ) {
     emit q->error( GData::Atom, i18n( "Could not get comments." ) );
@@ -642,15 +679,19 @@ void GDataPrivate::slotListAllComments( Syndication::Loader *loader,
                  KDateTime::Spec::UTC() ) );
     commentList.append( comment );
   }
-  kDebug(5323) << "Emitting listedRecentPosts()";
+  kDebug(5323) << "Emitting listedAllComments()";
   emit q->listedAllComments( commentList );
 }
 
 void GDataPrivate::slotListRecentPosts( Syndication::Loader *loader,
                                         Syndication::FeedPtr feed,
                                         Syndication::ErrorCode status ) {
+  kDebug(5323);
   Q_Q( GData );
-  Q_UNUSED( loader );
+  if( !loader ) {
+    kError(5323) << "loader is a null pointer.";
+    return;
+  }
 
   if ( status != Syndication::Success ) {
     emit q->error( GData::Atom, i18n( "Could not get posts." ) );
@@ -681,6 +722,7 @@ void GDataPrivate::slotListRecentPosts( Syndication::Loader *loader,
     kDebug(5323) << "QRegExp rx( 'post-(\\d+)' matches" << rx.cap(1);
     post.setTitle( ( *it )->title() );
     post.setContent( ( *it )->content() );
+    post.setLink( ( *it )->link() );
 //  FIXME: assuming UTC for now
     post.setCreationDateTime(
       KDateTime( QDateTime::fromTime_t( ( *it )->datePublished() ),
@@ -704,6 +746,10 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
 {
   kDebug(5323);
   Q_Q( GData );
+  if( !loader ) {
+    kError(5323) << "loader is a null pointer.";
+    return;
+  }
 
   bool success = false;
 
@@ -724,6 +770,7 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
       post->setTitle( ( *it )->title() );
       post->setContent( ( *it )->content() );
       post->setStatus( BlogPost::Fetched );
+      post->setLink( ( *it )->link() );
 //    FIXME: assuming UTC for now
       post->setCreationDateTime(
         KDateTime( QDateTime::fromTime_t( ( *it )->datePublished() ),
@@ -746,7 +793,11 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
 
 void GDataPrivate::slotCreatePostData( KIO::Job *job, const QByteArray &data )
 {
-  kDebug(5323) << "slotCreatePostData()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mCreatePostBuffer[ job ].size();
   mCreatePostBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mCreatePostBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -754,7 +805,11 @@ void GDataPrivate::slotCreatePostData( KIO::Job *job, const QByteArray &data )
 
 void GDataPrivate::slotCreatePost( KJob *job )
 {
-  kDebug(5323) << "slotCreatePost()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   const QString data = QString::fromUtf8( mCreatePostBuffer[ job ].data(),
                                           mCreatePostBuffer[ job ].size() );
   mCreatePostBuffer[ job ].resize( 0 );
@@ -808,6 +863,10 @@ void GDataPrivate::slotCreatePost( KJob *job )
 void GDataPrivate::slotModifyPostData( KIO::Job *job, const QByteArray &data )
 {
   kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mModifyPostBuffer[ job ].size();
   mModifyPostBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mModifyPostBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -815,7 +874,11 @@ void GDataPrivate::slotModifyPostData( KIO::Job *job, const QByteArray &data )
 
 void GDataPrivate::slotModifyPost( KJob *job )
 {
-  kDebug(5323) << "slotModifyPost()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   const QString data = QString::fromUtf8( mModifyPostBuffer[ job ].data(),
                                           mModifyPostBuffer[ job ].size() );
   mModifyPostBuffer[ job ].resize( 0 );
@@ -864,7 +927,11 @@ void GDataPrivate::slotModifyPost( KJob *job )
 
 void GDataPrivate::slotRemovePostData( KIO::Job *job, const QByteArray &data )
 {
-  kDebug(5323) << "slotRemovePostData()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mRemovePostBuffer[ job ].size();
   mRemovePostBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mRemovePostBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -872,7 +939,11 @@ void GDataPrivate::slotRemovePostData( KIO::Job *job, const QByteArray &data )
 
 void GDataPrivate::slotRemovePost( KJob *job )
 {
-  kDebug(5323) << "slotRemovePost()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   const QString data = QString::fromUtf8( mRemovePostBuffer[ job ].data(),
                                           mRemovePostBuffer[ job ].size() );
   mRemovePostBuffer[ job ].resize( 0 );
@@ -893,7 +964,11 @@ void GDataPrivate::slotRemovePost( KJob *job )
 
 void GDataPrivate::slotCreateCommentData( KIO::Job *job, const QByteArray &data )
 {
-  kDebug(5323) << "slotCreateCommentData()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mCreateCommentBuffer[ job ].size();
   mCreateCommentBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mCreateCommentBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -901,7 +976,11 @@ void GDataPrivate::slotCreateCommentData( KIO::Job *job, const QByteArray &data
 
 void GDataPrivate::slotCreateComment( KJob *job )
 {
-  kDebug(5323) << "slotCreateComment()";
+  kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   const QString data = QString::fromUtf8( mCreateCommentBuffer[ job ].data(),
                                           mCreateCommentBuffer[ job ].size() );
   mCreateCommentBuffer[ job ].resize( 0 );
@@ -957,6 +1036,10 @@ void GDataPrivate::slotCreateComment( KJob *job )
 void GDataPrivate::slotRemoveCommentData( KIO::Job *job, const QByteArray &data )
 {
   kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   unsigned int oldSize = mRemoveCommentBuffer[ job ].size();
   mRemoveCommentBuffer[ job ].resize( oldSize + data.size() );
   memcpy( mRemoveCommentBuffer[ job ].data() + oldSize, data.data(), data.size() );
@@ -965,6 +1048,10 @@ void GDataPrivate::slotRemoveCommentData( KIO::Job *job, const QByteArray &data
 void GDataPrivate::slotRemoveComment( KJob *job )
 {
   kDebug(5323);
+  if( !job ) {
+    kError(5323) << "job is a null pointer.";
+    return;
+  }
   const QString data = QString::fromUtf8( mRemoveCommentBuffer[ job ].data(),
                                           mRemoveCommentBuffer[ job ].size() );
   mRemoveCommentBuffer[ job ].resize( 0 );
