@@ -3,6 +3,7 @@
 
     Copyright (c) 1998 Preston Brown <pbrown@kde.org>
     Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (c) 2003 David Jarvie <software@astrojar.org.uk>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -24,14 +25,17 @@
   This file is part of the API for handling calendar data and
   defines the Alarm class.
 
-  @author Cornelius Schumacher
+  @brief
+  Represents an alarm notification.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
 */
 
-#include <kdebug.h>
-
+#include "alarm.h"
 #include "incidence.h"
 #include "todo.h"
-#include "alarm.h"
+
+#include <kdebug.h>
 
 using namespace KCal;
 
@@ -43,6 +47,31 @@ using namespace KCal;
 class KCal::Alarm::Private
 {
   public:
+    Private()
+      : mType( Alarm::Invalid ),
+        mAlarmSnoozeTime( 5 ),
+        mAlarmRepeatCount( 0 ),
+        mEndOffset( false ),
+        mHasTime( false ),
+        mAlarmEnabled( false )
+    {}
+    Private( const Private &other )
+      : mParent( other.mParent ),
+        mType( other.mType ),
+        mDescription( other.mDescription ),
+        mFile( other.mFile ),
+        mMailSubject( other.mMailSubject ),
+        mMailAttachFiles( other.mMailAttachFiles ),
+        mMailAddresses( other.mMailAddresses ),
+        mAlarmTime( other.mAlarmTime ),
+        mAlarmSnoozeTime( other.mAlarmSnoozeTime ),
+        mAlarmRepeatCount( other.mAlarmRepeatCount ),
+        mOffset( other.mOffset ),
+        mEndOffset( other.mEndOffset ),
+        mHasTime( other.mHasTime ),
+        mAlarmEnabled( other.mAlarmEnabled )
+    {}
+
     Incidence *mParent;  // the incidence which this alarm belongs to
 
     Type mType;          // type of alarm
@@ -52,10 +81,9 @@ class KCal::Alarm::Private
     QStringList mMailAttachFiles; // filenames to attach to email
     QList<Person> mMailAddresses; // who to mail for reminder
 
-    bool mAlarmEnabled;
     KDateTime mAlarmTime;// time at which to trigger the alarm
-    int mAlarmSnoozeTime;// number of minutes after alarm to
-                         // snooze before ringing again
+    Duration mAlarmSnoozeTime; // how long after alarm to snooze before
+                               // triggering again
     int mAlarmRepeatCount;// number of times for alarm to repeat
                           // after the initial time
 
@@ -63,21 +91,18 @@ class KCal::Alarm::Private
                          // to trigger the alarm
     bool mEndOffset;     // if true, mOffset relates to DTEND, not DTSTART
     bool mHasTime;       // use mAlarmTime, not mOffset
+    bool mAlarmEnabled;
 };
 //@endcond
 
 Alarm::Alarm( Incidence *parent ) : d( new KCal::Alarm::Private )
 {
   d->mParent = parent;
-  d->mType = Invalid;
-  d->mDescription = "";
-  d->mFile = "";
-  d->mMailSubject = "";
-  d->mAlarmSnoozeTime = 5;
-  d->mAlarmRepeatCount = 0;
-  d->mEndOffset = false;
-  d->mHasTime = false;
-  d->mAlarmEnabled = false;
+}
+
+Alarm::Alarm( const Alarm &other ) :
+  CustomProperties( other ), d( new KCal::Alarm::Private( *other.d ) )
+{
 }
 
 Alarm::~Alarm()
@@ -130,8 +155,9 @@ bool Alarm::operator==( const Alarm &rhs ) const
 
 void Alarm::setType( Alarm::Type type )
 {
-  if ( type == d->mType )
+  if ( type == d->mType ) {
     return;
+  }
 
   switch ( type ) {
     case Display:
@@ -154,7 +180,9 @@ void Alarm::setType( Alarm::Type type )
       return;
   }
   d->mType = type;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 Alarm::Type Alarm::type() const
@@ -166,14 +194,18 @@ void Alarm::setAudioAlarm( const QString &audioFile )
 {
   d->mType = Audio;
   d->mFile = audioFile;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 void Alarm::setAudioFile( const QString &audioFile )
 {
   if ( d->mType == Audio ) {
     d->mFile = audioFile;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -188,14 +220,18 @@ void Alarm::setProcedureAlarm( const QString &programFile,
   d->mType = Procedure;
   d->mFile = programFile;
   d->mDescription = arguments;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 void Alarm::setProgramFile( const QString &programFile )
 {
   if ( d->mType == Procedure ) {
     d->mFile = programFile;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -208,7 +244,9 @@ void Alarm::setProgramArguments( const QString &arguments )
 {
   if ( d->mType == Procedure ) {
     d->mDescription = arguments;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -226,7 +264,9 @@ void Alarm::setEmailAlarm( const QString &subject, const QString &text,
   d->mDescription = text;
   d->mMailAddresses = addressees;
   d->mMailAttachFiles = attachments;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 void Alarm::setMailAddress( const Person &mailAddress )
@@ -234,7 +274,9 @@ void Alarm::setMailAddress( const Person &mailAddress )
   if ( d->mType == Email ) {
     d->mMailAddresses.clear();
     d->mMailAddresses += mailAddress;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -242,7 +284,9 @@ void Alarm::setMailAddresses( const QList<Person> &mailAddresses )
 {
   if ( d->mType == Email ) {
     d->mMailAddresses = mailAddresses;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -250,7 +294,9 @@ void Alarm::addMailAddress( const Person &mailAddress )
 {
   if ( d->mType == Email ) {
     d->mMailAddresses += mailAddress;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -263,7 +309,9 @@ void Alarm::setMailSubject( const QString &mailAlarmSubject )
 {
   if ( d->mType == Email ) {
     d->mMailSubject = mailAlarmSubject;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -277,7 +325,9 @@ void Alarm::setMailAttachment( const QString &mailAttachFile )
   if ( d->mType == Email ) {
     d->mMailAttachFiles.clear();
     d->mMailAttachFiles += mailAttachFile;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -285,7 +335,9 @@ void Alarm::setMailAttachments( const QStringList &mailAttachFiles )
 {
   if ( d->mType == Email ) {
     d->mMailAttachFiles = mailAttachFiles;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -293,7 +345,9 @@ void Alarm::addMailAttachment( const QString &mailAttachFile )
 {
   if ( d->mType == Email ) {
     d->mMailAttachFiles += mailAttachFile;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -306,7 +360,9 @@ void Alarm::setMailText( const QString &text )
 {
   if ( d->mType == Email ) {
     d->mDescription = text;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -321,14 +377,18 @@ void Alarm::setDisplayAlarm( const QString &text )
   if ( !text.isNull() ) {
     d->mDescription = text;
   }
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 void Alarm::setText( const QString &text )
 {
   if ( d->mType == Display ) {
     d->mDescription = text;
-    if ( d->mParent ) d->mParent->updated();
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
   }
 }
 
@@ -342,7 +402,9 @@ void Alarm::setTime( const KDateTime &alarmTime )
   d->mAlarmTime = alarmTime;
   d->mHasTime = true;
 
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 KDateTime Alarm::time() const
@@ -368,22 +430,27 @@ bool Alarm::hasTime() const
   return d->mHasTime;
 }
 
-void Alarm::shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec)
+void Alarm::shiftTimes( const KDateTime::Spec &oldSpec,
+                        const KDateTime::Spec &newSpec )
 {
   d->mAlarmTime = d->mAlarmTime.toTimeSpec( oldSpec );
   d->mAlarmTime.setTimeSpec( newSpec );
-  if ( d->mParent ) d->mParent->updated();
-}
-
-void Alarm::setSnoozeTime( int alarmSnoozeTime )
-{
-  if ( alarmSnoozeTime > 0 ) {
-    d->mAlarmSnoozeTime = alarmSnoozeTime;
-    if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
   }
 }
 
-int Alarm::snoozeTime() const
+void Alarm::setSnoozeTime( const Duration &alarmSnoozeTime )
+{
+  if ( alarmSnoozeTime.value() > 0 ) {
+    d->mAlarmSnoozeTime = alarmSnoozeTime;
+    if ( d->mParent ) {
+      d->mParent->updated();
+    }
+  }
+}
+
+Duration Alarm::snoozeTime() const
 {
   return d->mAlarmSnoozeTime;
 }
@@ -391,7 +458,9 @@ int Alarm::snoozeTime() const
 void Alarm::setRepeatCount( int alarmRepeatCount )
 {
   d->mAlarmRepeatCount = alarmRepeatCount;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 int Alarm::repeatCount() const
@@ -399,9 +468,10 @@ int Alarm::repeatCount() const
   return d->mAlarmRepeatCount;
 }
 
-int Alarm::duration() const
+Duration Alarm::duration() const
 {
-  return d->mAlarmRepeatCount * d->mAlarmSnoozeTime * 60;
+  return Duration( d->mAlarmSnoozeTime.value() * d->mAlarmRepeatCount,
+                   d->mAlarmSnoozeTime.type() );
 }
 
 KDateTime Alarm::nextRepetition( const KDateTime &preTime ) const
@@ -414,13 +484,24 @@ KDateTime Alarm::nextRepetition( const KDateTime &preTime ) const
     // there isn't an occurrence after the specified time
     return KDateTime();
   }
-  int snoozeSecs = d->mAlarmSnoozeTime * 60;
-  int repetition = at.secsTo_long( preTime ) / snoozeSecs + 1;
+  int repetition;
+  int interval = d->mAlarmSnoozeTime.value();
+  bool daily = d->mAlarmSnoozeTime.isDaily();
+  if ( daily ) {
+    int daysTo = at.daysTo( preTime );
+    if ( !preTime.isDateOnly() && preTime.time() <= at.time() ) {
+      --daysTo;
+    }
+    repetition = daysTo / interval + 1;
+  } else {
+    repetition = at.secsTo_long( preTime ) / interval + 1;
+  }
   if ( repetition > d->mAlarmRepeatCount ) {
     // all repetitions have finished before the specified time
     return KDateTime();
   }
-  return at.addSecs( repetition * snoozeSecs );
+  return daily ? at.addDays( repetition * interval )
+               : at.addSecs( repetition * interval );
 }
 
 KDateTime Alarm::previousRepetition( const KDateTime &afterTime ) const
@@ -433,33 +514,51 @@ KDateTime Alarm::previousRepetition( const KDateTime &afterTime ) const
   if ( !d->mAlarmRepeatCount ) {
     return at;
   }
-  int snoozeSecs = d->mAlarmSnoozeTime * 60;
-  int repetition = ( at.secsTo_long( afterTime ) - 1 ) / snoozeSecs;
+  int repetition;
+  int interval = d->mAlarmSnoozeTime.value();
+  bool daily = d->mAlarmSnoozeTime.isDaily();
+  if ( daily ) {
+    int daysTo = at.daysTo( afterTime );
+    if ( afterTime.isDateOnly() || afterTime.time() <= at.time() ) {
+      --daysTo;
+    }
+    repetition = daysTo / interval;
+  } else {
+    repetition = ( at.secsTo_long( afterTime ) - 1 ) / interval;
+  }
   if ( repetition > d->mAlarmRepeatCount ) {
     repetition = d->mAlarmRepeatCount;
   }
-  return at.addSecs( repetition * snoozeSecs );
+  return daily ? at.addDays( repetition * interval )
+               : at.addSecs( repetition * interval );
 }
 
 KDateTime Alarm::endTime() const
 {
-  if ( d->mAlarmRepeatCount ) {
-    return time().addSecs( d->mAlarmRepeatCount * d->mAlarmSnoozeTime * 60 );
-  } else {
+  if ( !d->mAlarmRepeatCount ) {
     return time();
   }
+  if ( d->mAlarmSnoozeTime.isDaily() ) {
+    return time().addDays( d->mAlarmRepeatCount * d->mAlarmSnoozeTime.asDays() );
+  } else {
+    return time().addSecs( d->mAlarmRepeatCount * d->mAlarmSnoozeTime.asSeconds() );
+  }
 }
 
 void Alarm::toggleAlarm()
 {
   d->mAlarmEnabled = !d->mAlarmEnabled;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 void Alarm::setEnabled( bool enable )
 {
   d->mAlarmEnabled = enable;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 bool Alarm::enabled() const
@@ -472,7 +571,9 @@ void Alarm::setStartOffset( const Duration &offset )
   d->mOffset = offset;
   d->mEndOffset = false;
   d->mHasTime = false;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 Duration Alarm::startOffset() const
@@ -495,7 +596,9 @@ void Alarm::setEndOffset( const Duration &offset )
   d->mOffset = offset;
   d->mEndOffset = true;
   d->mHasTime = false;
-  if ( d->mParent ) d->mParent->updated();
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
 
 Duration Alarm::endOffset() const
@@ -515,14 +618,7 @@ Incidence *Alarm::parent() const
 
 void Alarm::customPropertyUpdated()
 {
-  if ( d->mParent ) d->mParent->updated();
-}
-
-// DEPRECATED methods
-void Alarm::setTime( const QDateTime &alarmTime )
-{
-  if (d->mParent && d->mParent->dtStart().isValid())   // use start as best guess for time zone
-    setTime(KDateTime(alarmTime, d->mParent->dtStart().timeSpec()));
-  else
-    setTime(KDateTime(alarmTime));  // use local time zone
+  if ( d->mParent ) {
+    d->mParent->updated();
+  }
 }
