@@ -81,7 +81,7 @@ const int gSecondsPerWeek   = gSecondsPerDay    * 7;
 class ToComponentVisitor : public IncidenceBase::Visitor
 {
   public:
-    ToComponentVisitor( ICalFormatImpl *impl, Scheduler::Method m )
+    ToComponentVisitor( ICalFormatImpl *impl, iTIPMethod m )
       : mImpl( impl ), mComponent( 0 ), mMethod( m ) {}
 
     bool visit( Event *e )
@@ -113,7 +113,7 @@ class ToComponentVisitor : public IncidenceBase::Visitor
   private:
     ICalFormatImpl *mImpl;
     icalcomponent *mComponent;
-    Scheduler::Method mMethod;
+    iTIPMethod mMethod;
 };
 
 class ICalFormatImpl::Private
@@ -157,7 +157,7 @@ QString ICalFormatImpl::loadedProductId() const
 }
 
 icalcomponent *ICalFormatImpl::writeIncidence( IncidenceBase *incidence,
-                                               Scheduler::Method method )
+                                               iTIPMethod method )
 {
   ToComponentVisitor v( this, method );
   if ( incidence->accept(v) ) {
@@ -181,7 +181,7 @@ icalcomponent *ICalFormatImpl::writeTodo( Todo *todo, ICalTimeZones *tzlist,
   icalproperty *prop;
   if ( todo->hasDueDate() ) {
     icaltimetype due;
-    if ( todo->floats() ) {
+    if ( todo->allDay() ) {
       due = writeICalDate( todo->dtDue( true ).date() );
       prop = icalproperty_new_due(due);
     } else {
@@ -194,7 +194,7 @@ icalcomponent *ICalFormatImpl::writeTodo( Todo *todo, ICalTimeZones *tzlist,
   // start time
   if ( todo->hasStartDate() || todo->recurs() ) {
     icaltimetype start;
-    if ( todo->floats() ) {
+    if ( todo->allDay() ) {
       start = writeICalDate( todo->dtStart( true ).date() );
       prop = icalproperty_new_dtstart( start );
     } else {
@@ -239,7 +239,7 @@ icalcomponent *ICalFormatImpl::writeEvent( Event *event,
   // start time
   icalproperty *prop;
   icaltimetype start;
-  if ( event->floats() ) {
+  if ( event->allDay() ) {
     start = writeICalDate( event->dtStart().date() );
     prop = icalproperty_new_dtstart( start );
   } else {
@@ -253,7 +253,7 @@ icalcomponent *ICalFormatImpl::writeEvent( Event *event,
     // RFC2445 says that if DTEND is present, it has to be greater than DTSTART.
     icaltimetype end;
     KDateTime dt = event->dtEnd();
-    if ( event->floats() ) {
+    if ( event->allDay() ) {
       // +1 day because end date is non-inclusive.
       end = writeICalDate( dt.date().addDays( 1 ) );
       icalcomponent_add_property( vevent, icalproperty_new_dtend(end) );
@@ -295,7 +295,7 @@ icalcomponent *ICalFormatImpl::writeEvent( Event *event,
 }
 
 icalcomponent *ICalFormatImpl::writeFreeBusy( FreeBusy *freebusy,
-                                              Scheduler::Method method )
+                                              iTIPMethod method )
 {
   icalcomponent *vfreebusy = icalcomponent_new( ICAL_VFREEBUSY_COMPONENT );
 
@@ -307,7 +307,7 @@ icalcomponent *ICalFormatImpl::writeFreeBusy( FreeBusy *freebusy,
   icalcomponent_add_property(
     vfreebusy, icalproperty_new_dtend( writeICalUtcDateTime( freebusy->dtEnd() ) ) );
 
-  if ( method == Scheduler::Request ) {
+  if ( method == iTIPRequest ) {
     icalcomponent_add_property(
       vfreebusy, icalproperty_new_uid( freebusy->uid().toUtf8() ) );
   }
@@ -342,7 +342,7 @@ icalcomponent *ICalFormatImpl::writeJournal( Journal *journal,
   KDateTime dt = journal->dtStart();
   if ( dt.isValid() ) {
     icaltimetype start;
-    if ( journal->floats() ) {
+    if ( journal->allDay() ) {
       start = writeICalDate( dt.date() );
       prop = icalproperty_new_dtstart( start );
     } else {
@@ -562,6 +562,7 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
   }
 }
 
+//@cond PRIVATE
 void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
                                                   IncidenceBase *incidenceBase )
 {
@@ -605,6 +606,7 @@ void ICalFormatImpl::Private::writeCustomProperties( icalcomponent *parent,
     icalcomponent_add_property( parent, p );
   }
 }
+//@endcond
 
 icalproperty *ICalFormatImpl::writeOrganizer( const Person &organizer )
 {
@@ -886,7 +888,7 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
   } else if ( recur->duration() == -1 ) {
     r.count = 0;
   } else {
-    if ( recur->floats() ) {
+    if ( recur->allDay() ) {
       r.until = writeICalDate( recur->endDt().date() );
     } else {
       r.until = writeICalUtcDateTime( recur->endDt() );
@@ -1023,7 +1025,7 @@ Todo *ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist )
         todo->setDtDue( KDateTime( kdt.date(), todo->dtStart().timeSpec() ), true );
       } else {
         todo->setDtDue( kdt, true );
-        todo->setFloats( false );
+        todo->setAllDay( false );
       }
       todo->setHasDueDate( true );
       break;
@@ -1100,7 +1102,7 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, ICalTimeZones *tzlist )
         event->setDtEnd( KDateTime( endDate, event->dtStart().timeSpec() ) );
       } else {
         event->setDtEnd( kdt );
-        event->setFloats( false );
+        event->setAllDay( false );
       }
       dtEndProcessed = true;
       break;
@@ -1135,9 +1137,9 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, ICalTimeZones *tzlist )
 
   QString msade = event->nonKDECustomProperty( "X-MICROSOFT-CDO-ALLDAYEVENT" );
   if ( !msade.isNull() ) {
-    bool floats = ( msade == QLatin1String( "TRUE" ) );
-    event->setFloats( floats );
-    if ( floats ) {
+    bool allDay = ( msade == QLatin1String( "TRUE" ) );
+    event->setAllDay( allDay );
+    if ( allDay ) {
       KDateTime endDate = event->dtEnd();
       event->setDtEnd( endDate.addDays( -1 ) );
     }
@@ -1413,7 +1415,7 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
     case ICAL_DTSTART_PROPERTY:  // start date and time
       kdt = readICalDateTimeProperty( p, tzlist );
       incidence->setDtStart( kdt );
-      incidence->setFloats( kdt.isDateOnly() );
+      incidence->setAllDay( kdt.isDateOnly() );
       break;
 
     case ICAL_DURATION_PROPERTY:  // start date and time
@@ -1607,6 +1609,7 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
   }
 }
 
+//@cond PRIVATE
 void ICalFormatImpl::Private::readIncidenceBase( icalcomponent *parent,
                                                  IncidenceBase *incidenceBase )
 {
@@ -1664,6 +1667,7 @@ void ICalFormatImpl::Private::readCustomProperties( icalcomponent *parent,
 
   properties->setCustomProperties( customProperties );
 }
+//@endcond
 
 void ICalFormatImpl::readRecurrenceRule( icalproperty *rrule,
                                          Incidence *incidence )
@@ -1750,6 +1754,7 @@ void ICalFormatImpl::readRecurrence( const struct icalrecurrencetype &r,
   int i;
   int index = 0;
 
+//@cond PRIVATE
 #define readSetByList( rrulecomp, setfunc )                             \
   index = 0;                                                            \
   lst.clear();                                                          \
@@ -1759,6 +1764,7 @@ void ICalFormatImpl::readRecurrence( const struct icalrecurrencetype &r,
   if ( !lst.isEmpty() ) {                                               \
     recur->setfunc( lst );                                              \
   }
+//@endcond
 
   // BYSECOND, MINUTE and HOUR, MONTHDAY, YEARDAY, WEEKNUMBER, MONTH
   // and SETPOS are standard int lists, so we can treat them with the
@@ -2441,35 +2447,35 @@ void ICalFormatImpl::dumpIcalRecurrence( icalrecurrencetype r )
 }
 
 icalcomponent *ICalFormatImpl::createScheduleComponent( IncidenceBase *incidence,
-                                                        Scheduler::Method method )
+                                                        iTIPMethod method )
 {
   icalcomponent *message = createCalendarComponent();
 
   icalproperty_method icalmethod = ICAL_METHOD_NONE;
 
   switch (method) {
-  case Scheduler::Publish:
+  case iTIPPublish:
     icalmethod = ICAL_METHOD_PUBLISH;
     break;
-  case Scheduler::Request:
+  case iTIPRequest:
     icalmethod = ICAL_METHOD_REQUEST;
     break;
-  case Scheduler::Refresh:
+  case iTIPRefresh:
     icalmethod = ICAL_METHOD_REFRESH;
     break;
-  case Scheduler::Cancel:
+  case iTIPCancel:
     icalmethod = ICAL_METHOD_CANCEL;
     break;
-  case Scheduler::Add:
+  case iTIPAdd:
     icalmethod = ICAL_METHOD_ADD;
     break;
-  case Scheduler::Reply:
+  case iTIPReply:
     icalmethod = ICAL_METHOD_REPLY;
     break;
-  case Scheduler::Counter:
+  case iTIPCounter:
     icalmethod = ICAL_METHOD_COUNTER;
     break;
-  case Scheduler::Declinecounter:
+  case iTIPDeclineCounter:
     icalmethod = ICAL_METHOD_DECLINECOUNTER;
     break;
   default:
