@@ -52,7 +52,11 @@ using namespace KCal;
 class KCal::IncidenceBase::Private
 {
   public:
-    Private() : mAllDay( true ), mHasDuration( false )
+    Private()
+      : mUpdateGroupLevel( 0 ),
+        mUpdatedPending( false ),
+        mAllDay( true ),
+        mHasDuration( false )
     { mAttendees.setAutoDelete( true ); }
 
     Private( const Private &other )
@@ -61,6 +65,8 @@ class KCal::IncidenceBase::Private
         mOrganizer( other.mOrganizer ),
         mUid( other.mUid ),
         mDuration( other.mDuration ),
+        mUpdateGroupLevel( 0 ),
+        mUpdatedPending( false ),
         mAllDay( other.mAllDay ),
         mHasDuration( other.mHasDuration )
         //????? mComments
@@ -73,6 +79,8 @@ class KCal::IncidenceBase::Private
     Person mOrganizer;           // incidence person (owner)
     QString mUid;                // incidence unique id
     Duration mDuration;          // incidence duration
+    int mUpdateGroupLevel;       // if non-zero, suppresses update() calls
+    bool mUpdatedPending;        // true if an update has occurred since startUpdates()
     bool mAllDay;                // true if the incidence is all-day
     bool mHasDuration;           // true if the incidence has a duration
 
@@ -434,8 +442,27 @@ void IncidenceBase::unRegisterObserver( IncidenceBase::IncidenceObserver *observ
 
 void IncidenceBase::updated()
 {
-  foreach ( IncidenceObserver *o, d->mObservers ) {
-    o->incidenceUpdated( this );
+  if ( d->mUpdateGroupLevel ) {
+    d->mUpdatedPending = true;
+  } else {
+    foreach ( IncidenceObserver *o, d->mObservers ) {
+      o->incidenceUpdated( this );
+    }
+  }
+}
+
+void IncidenceBase::startUpdates()
+{
+  ++d->mUpdateGroupLevel;
+}
+
+void IncidenceBase::endUpdates()
+{
+  if ( d->mUpdateGroupLevel > 0 ) {
+    if ( --d->mUpdateGroupLevel == 0 && d->mUpdatedPending ) {
+      d->mUpdatedPending = false;
+      updated();
+    }
   }
 }
 
