@@ -93,9 +93,9 @@ static QString eventViewerFormatCategories( Incidence *event )
   QString tmpStr;
   if ( !event->categoriesStr().isEmpty() ) {
     if ( event->categories().count() == 1 ) {
-      tmpStr = eventViewerAddTag( "h2", i18n( "Category" ) );
+      tmpStr = eventViewerAddTag( "h3", i18n( "Category" ) );
     } else {
-      tmpStr = eventViewerAddTag( "h2", i18n( "Categories" ) );
+      tmpStr = eventViewerAddTag( "h3", i18n( "Categories" ) );
     }
     tmpStr += eventViewerAddTag( "p", event->categoriesStr() );
   }
@@ -159,17 +159,17 @@ static QString eventViewerFormatAttendees( Incidence *event )
   Attendee::List attendees = event->attendees();
   if ( attendees.count() ) {
     KIconLoader *iconLoader = KIconLoader::global();
-    const QString iconPath = iconLoader->iconPath( "mail", KIconLoader::Small );
+    const QString iconPath = iconLoader->iconPath( "mail-message-new", KIconLoader::Small );
 
     // Add organizer link
-    tmpStr += eventViewerAddTag( "h3", i18n( "Organizer" ) );
+    tmpStr += eventViewerAddTag( "h4", i18n( "Organizer" ) );
     tmpStr += "<ul>";
     tmpStr += linkPerson( event->organizer().email(), event->organizer().name(),
                           QString(), iconPath );
     tmpStr += "</ul>";
 
     // Add attendees links
-    tmpStr += eventViewerAddTag( "h3", i18n( "Attendees" ) );
+    tmpStr += eventViewerAddTag( "h4", i18n( "Attendees" ) );
     tmpStr += "<ul>";
     Attendee::List::ConstIterator it;
     for ( it = attendees.begin(); it != attendees.end(); ++it ) {
@@ -221,7 +221,7 @@ static QString eventViewerFormatBirthday( Event *event )
   QString email_1= event->customProperty( "KABC", "EMAIL-1" );
 
   KIconLoader *iconLoader = KIconLoader::global();
-  const QString iconPath = iconLoader->iconPath( "mail", KIconLoader::Small );
+  const QString iconPath = iconLoader->iconPath( "mail-message-new", KIconLoader::Small );
   //TODO: add a tart icon
   QString tmpString = "<ul>";
   tmpString += linkPerson( email_1, name_1, uid_1, iconPath );
@@ -242,6 +242,8 @@ static QString eventViewerFormatHeader( Incidence *incidence )
   QString tmpStr = "<table><tr>";
 
   // show icons
+  /* all of those icons currently don't exist, makes no sense currently
+     to load a set of "unknown" icons. re-enable when those are available.
   {
     KIconLoader *iconLoader = KIconLoader::global();
     tmpStr += "<td>";
@@ -261,8 +263,9 @@ static QString eventViewerFormatHeader( Incidence *incidence )
 
     tmpStr += "</td>";
   }
+  */
 
-  tmpStr += "<td>" + eventViewerAddTag( "h1", incidence->summary() ) + "</td>";
+  tmpStr += "<td>" + eventViewerAddTag( "h2", incidence->summary() ) + "</td>";
   tmpStr += "</tr></table><br>";
 
   return tmpStr;
@@ -342,7 +345,8 @@ static QString eventViewerFormatEvent( Event *event )
   if ( event->categories().count() > 0 ) {
     tmpStr += "<tr>";
     tmpStr += "<td align=\"right\"><b>";
-    tmpStr += i18np( "1 category", "%1 categories", event->categories().count() )+ "</b></td>";
+    tmpStr += i18np( "1&nbsp;category", "%1&nbsp;categories", event->categories().count() ) +
+              "</b></td>";
     tmpStr += "<td>" + event->categoriesStr() + "</td>";
     tmpStr += "</tr>";
   }
@@ -364,7 +368,7 @@ static QString eventViewerFormatEvent( Event *event )
   if ( attachmentCount > 0 ) {
     tmpStr += "<tr>";
     tmpStr += "<td align=\"right\"><b>";
-    tmpStr += i18np( "1 attachment", "%1 attachments", attachmentCount )+ "</b></td>";
+    tmpStr += i18np( "1&nbsp;attachment", "%1&nbsp;attachments", attachmentCount )+ "</b></td>";
     tmpStr += "<td>" + eventViewerFormatAttachments( event ) + "</td>";
     tmpStr += "</tr>";
   }
@@ -428,10 +432,10 @@ static QString eventViewerFormatJournal( Journal *journal )
 
   QString tmpStr;
   if ( !journal->summary().isEmpty() ) {
-    tmpStr+= eventViewerAddTag( "h1", journal->summary() );
+    tmpStr+= eventViewerAddTag( "h2", journal->summary() );
   }
   tmpStr += eventViewerAddTag(
-    "h2", i18n( "Journal for %1",
+    "h3", i18n( "Journal for %1",
                 journal->dtStartDateStr( false, journal->dtStart().timeSpec() ) ) );
   if ( !journal->description().isEmpty() ) {
     tmpStr += eventViewerAddTag( "p", journal->description() );
@@ -447,9 +451,9 @@ static QString eventViewerFormatFreeBusy( FreeBusy *fb )
 
   QString tmpStr(
     eventViewerAddTag(
-      "h1", i18n( "Free/Busy information for %1", fb->organizer().fullName() ) ) );
+      "h2", i18n( "Free/Busy information for %1", fb->organizer().fullName() ) ) );
   tmpStr += eventViewerAddTag(
-    "h3", i18n( "Busy times in date range %1 - %2:",
+    "h4", i18n( "Busy times in date range %1 - %2:",
                 KGlobal::locale()->formatDate( fb->dtStart().date(), KLocale::ShortDate ),
                 KGlobal::locale()->formatDate( fb->dtEnd().date(), KLocale::ShortDate ) ) );
 
@@ -755,7 +759,7 @@ static QString invitationHeaderEvent( Event *event, ScheduleMessage *msg )
     return i18n( "This event has been published" );
   case iTIPRequest:
     if ( event->revision() > 0 ) {
-      return i18n( "<h2>This meeting has been updated</h2>" );
+      return i18n( "<h3>This meeting has been updated</h3>" );
     } else {
       return i18n( "You have been invited to this meeting" );
     }
@@ -1120,7 +1124,7 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
   if ( !headerVisitor.act( incBase, msg ) ) {
     return QString();
   }
-  html += "<h2>" + headerVisitor.result() + "</h2>";
+  html += "<h3>" + headerVisitor.result() + "</h3>";
 
   InvitationBodyVisitor bodyVisitor;
   if ( !bodyVisitor.act( incBase, msg ) ) {
