@@ -3,10 +3,9 @@
     FILE: icalclassify.c
     CREATOR: ebusboom 23 aug 2000
   
-    $Id: icalclassify.c 618274 2006-12-31 21:00:36Z kainhofe $
-    $Locker:  $
     
-    (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>, http://www.softwarestudio.org
+    (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+        http://www.softwarestudio.org
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of either: 
@@ -22,10 +21,7 @@
 
     ======================================================================*/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
+#include "config-libical.h"
 #include "ical.h"
 #include "icalclassify.h"
 #include "icalmemory.h"
@@ -170,10 +166,10 @@ void icalssutil_get_parts(icalcomponent* c,
 
     p = icalcomponent_get_first_property(inner,ICAL_ORGANIZER_PROPERTY);
     if(p!=0){
-      const char *p_organizer = icalproperty_get_organizer(p); 
-      if (p_organizer!=0) { 
-        parts->organizer = strdup(p_organizer); 
-      } 
+      const char *p_organizer = icalproperty_get_organizer(p);
+      if (p_organizer!=0) {
+        parts->organizer = strdup(p_organizer);
+      }
     }
 
     p = icalcomponent_get_first_property(inner,ICAL_SEQUENCE_PROPERTY);    
@@ -183,10 +179,10 @@ void icalssutil_get_parts(icalcomponent* c,
 
     p = icalcomponent_get_first_property(inner,ICAL_UID_PROPERTY);
     if(p!=0){
-      const char *p_uid = icalproperty_get_uid(p); 
-      if (p_uid!=0) { 
-        parts->uid = strdup(p_uid); 
-      } 
+      const char *p_uid = icalproperty_get_uid(p);
+      if (p_uid!=0) {
+        parts->uid = strdup(p_uid);
+      }
     }
 
     p = icalcomponent_get_first_property(inner,ICAL_RECURRENCEID_PROPERTY);
