@@ -24,23 +24,23 @@
   This file is part of the API for handling calendar data and
   defines the Person class.
 
-  @author Cornelius Schumacher
-  @author Reinhold Kainhofer
+  @brief
+  Represents a person, by name ane email address.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
 */
 
 #ifndef KCAL_PERSON_H
 #define KCAL_PERSON_H
 
-#include <QString>
+#include <QtCore/QString>
 
-#include "kcal.h"
+#include "kcal_export.h"
 
 namespace KCal {
 
 /**
-  @brief
-  Represents a person.
-
   This class represents a person, with a name and an email address.
   It supports the "FirstName LastName <emailaddress>" format.
 */
