@@ -27,30 +27,27 @@
 #include <kcomponentdata.h>
 #include <kcmdlineargs.h>
 
-#include <QCoreApplication>
-#include <QFile>
-#include <QFileInfo>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
 
 using namespace KCal;
 
-static const KCmdLineOptions options[] =
-{
-  { "verbose", "Verbose output", 0 },
-  { "+input", "Name of input file", 0 },
-  { "+output", "Name of output file", 0 },
-  KCmdLineLastOption
-};
-
 int main( int argc, char **argv )
 {
-  KAboutData aboutData( "readandwrite", "Read and Write Calendar", "0.1" );
+  KAboutData aboutData( "readandwrite", 0, ki18n("Read and Write Calendar"), "0.1" );
   KCmdLineArgs::init( argc, argv, &aboutData );
+
+  KCmdLineOptions options;
+  options.add("verbose", ki18n("Verbose output"));
+  options.add("+input", ki18n("Name of input file"));
+  options.add("+output", ki18n("Name of output file"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KComponentData componentData( &aboutData ); // needed by KConfig used by KSaveFile
 
   // Not needed, so let's save time
-  //QCoreApplication app( *KCmdLineArgs::qt_argc(), *KCmdLineArgs::qt_argv() );
+  //QCoreApplication app( KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -58,14 +55,14 @@ int main( int argc, char **argv )
     args->usage( "Wrong number of arguments." );
   }
 
-  QString input = QFile::decodeName( args->arg( 0 ) );
-  QString output = QFile::decodeName( args->arg( 1 ) );
+  QString input = args->arg( 0 );
+  QString output = args->arg( 1 );
 
   QFileInfo outputFileInfo( output );
   output = outputFileInfo.absoluteFilePath();
 
-  kDebug(5800) << "Input file: " << input << endl;
-  kDebug(5800) << "Output file: " << output << endl;
+  kDebug(5800) << "Input file:" << input;
+  kDebug(5800) << "Output file:" << output;
 
 
   CalendarLocal cal( KDateTime::UTC );
