@@ -27,31 +27,28 @@
 #include <kdebug.h>
 #include <kcmdlineargs.h>
 
-#include <QFile>
-#include <QTextStream>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 
 
 using namespace KCal;
 
 
-static const KCmdLineOptions options[] =
-{
-  { "verbose", "Verbose output", 0 },
-  { "+input", "Name of input file", 0 },
-  { "[+output]", "optional name of output file for the recurrence dates", 0 },
-  KCmdLineLastOption
-};
-
 
 int main( int argc, char **argv )
 {
-  KAboutData aboutData( "testrecurson", "Tests all dates from 2002 to 2010 to test if the event recurs on each individual date. This is meant to test the Recurrence::recursOn method for errors.", "0.1" );
+  KAboutData aboutData( "testrecurson", 0, ki18n("Tests all dates from 2002 to 2010 to test if the event recurs on each individual date. This is meant to test the Recurrence::recursOn method for errors."), "0.1" );
   KCmdLineArgs::init( argc, argv, &aboutData );
+
+  KCmdLineOptions options;
+  options.add("verbose", ki18n("Verbose output"));
+  options.add("+input", ki18n("Name of input file"));
+  options.add("[+output]", ki18n("optional name of output file for the recurrence dates"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KComponentData componentData( &aboutData );
-  //QCoreApplication app( *KCmdLineArgs::qt_argc(), *KCmdLineArgs::qt_argv() );
+  //QCoreApplication app( KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -59,19 +56,19 @@ int main( int argc, char **argv )
     args->usage( "Wrong number of arguments." );
   }
 
-  QString input = QFile::decodeName( args->arg( 0 ) );
-//   kDebug(5800) << "Input file: " << input << endl;
+  QString input = args->arg( 0 );
+//   kDebug(5800) << "Input file:" << input;
 
   QTextStream *outstream;
   outstream = 0;
   QString fn("");
   if ( args->count() > 1 ) {
     fn = args->arg( 1 );
-//     kDebug() << "We have a file name given: " << fn << endl;
+//     kDebug() << "We have a file name given:" << fn;
   }
   QFile outfile( fn );
   if ( !fn.isEmpty() && outfile.open( QIODevice::WriteOnly ) ) {
-//     kDebug() << "Opened output file!!!" << endl;
+//     kDebug() << "Opened output file!!!";
     outstream = new QTextStream( &outfile );
   }
 
@@ -87,8 +84,8 @@ int main( int argc, char **argv )
 
   for ( Incidence::List::Iterator it = inc.begin(); it != inc.end(); ++it ) {
     Incidence *incidence = *it;
-//     kDebug(5800) << "*+*+*+*+*+*+*+*+*+*" << endl;
-//     kDebug(5800) << " -> " << incidence->summary() << " <- " << endl;
+//     kDebug(5800) << "*+*+*+*+*+*+*+*+*+*";
+//     kDebug(5800) << " ->" << incidence->summary() << "<-";
 
 //     incidence->recurrence()->dump();
 
@@ -107,7 +104,7 @@ int main( int argc, char **argv )
       dt = QDate( 2005, 1, 1 );
       while ( dt.year() < 2007 ) {
         if ( incidence->recursOn( dt, cal.viewTimeSpec() ) )
-          kDebug(5800) << dt.toString( Qt::ISODate ) << endl;
+          kDebug(5800) << dt.toString( Qt::ISODate );
         dt = dt.addDays( 1 );
       }
     }
