@@ -250,6 +250,11 @@ void Todo::setHasStartDate( bool f )
   updated();
 }
 
+KDateTime Todo::dtStart() const
+{
+  return dtStart( false );
+}
+
 KDateTime Todo::dtStart( bool first ) const
 {
   if ( recurs() && !first ) {
@@ -285,6 +290,11 @@ QString Todo::dtStartTimeStr( bool shortfmt, bool first, const KDateTime::Spec &
   }
 }
 
+QString Todo::dtStartTimeStr( bool shortfmt, const KDateTime::Spec &spec ) const
+{
+  return Incidence::dtStartTimeStr( shortfmt, spec );
+}
+
 QString Todo::dtStartDateStr( bool shortfmt, bool first, const KDateTime::Spec &spec ) const
 {
   if ( spec.isValid() ) {
@@ -305,6 +315,11 @@ QString Todo::dtStartDateStr( bool shortfmt, bool first, const KDateTime::Spec &
   }
 }
 
+QString Todo::dtStartDateStr( bool shortfmt, const KDateTime::Spec &spec ) const
+{
+  return Incidence::dtStartDateStr( shortfmt, spec );
+}
+
 QString Todo::dtStartStr( bool shortfmt, bool first, const KDateTime::Spec &spec ) const
 {
   if ( spec.isValid() ) {
@@ -325,6 +340,11 @@ QString Todo::dtStartStr( bool shortfmt, bool first, const KDateTime::Spec &spec
   }
 }
 
+QString Todo::dtStartStr( bool shortfmt, const KDateTime::Spec &spec ) const
+{
+  return Incidence::dtStartStr( shortfmt, spec );
+}
+
 bool Todo::isCompleted() const
 {
   if ( d->mPercentComplete == 100 ) {
