@@ -1449,7 +1449,7 @@ void VCalFormat::populate( VObject *vcal )
     methodType = fakeCString( vObjectUStringZValue( curVO ) );
     kDebug(5800) << "This calendar is an iTIP transaction of type '"
                  << methodType << "'";
-    delete methodType;
+    deleteStr( methodType );
   }
 
   // warn the user that we might have trouble reading non-known calendar.
