@@ -122,7 +122,10 @@ imapParser::sendCommand (imapCommand * aCmd)
            || command == "GETANNOTATION"
            || command == "NAMESPACE"
            || command == "GETQUOTAROOT"
-           || command == "GETQUOTA")
+           || command == "GETQUOTA"
+           || command == "X-GET-OTHER-USERS"
+           || command == "X-GET-DELEGATES"
+           || command == "X-GET-OUT-OF-OFFICE")
   {
     lastResults.clear ();
   }
@@ -154,7 +157,7 @@ imapParser::clientLogin (const QString & aUser, const QString & aPass,
   }
   resultInfo = cmd->resultInfo();
   completeQueue.removeAll (cmd);
-
+  delete cmd;
   return retVal;
 }
 
@@ -270,7 +273,9 @@ imapParser::clientAuthenticate ( KIO::SlaveBase *slave, KIO::AuthInfo &ai,
   while ( true )
   {
     //read the next line
-    while (parseLoop() == 0);
+    while (parseLoop() == 0) {
+      ;
+    }
     if ( cmd->isComplete() ) break;
 
     if (!continuation.isEmpty())
@@ -370,6 +375,15 @@ imapParser::parseUntagged (parseString & result)
     if (what[1] == 'K' && what.size() == 2)
     {
       parseResult (what, result);
+    } else if (qstrncmp(what, "OTHER-USER", 10) == 0) { // X-GET-OTHER-USER
+      parseOtherUser (result);
+    } else if (qstrncmp(what, "OUT-OF-OFFICE", 13) == 0) { // X-GET-OUT-OF-OFFICE
+      parseOutOfOffice (result);
+    }
+    break;
+  case 'D':
+    if (qstrncmp(what, "DELEGATE", 8) == 0) { // X-GET-DELEGATES
+      parseDelegate (result);
     }
     break;
 
@@ -447,7 +461,12 @@ imapParser::parseUntagged (parseString & result)
     {
       parseQuota( result );
     }
-
+    break;
+  case 'X': // Custom command
+    {
+      parseCustom( result );
+    }
+    break;
   default:
     //better be a number
     {
@@ -773,6 +792,40 @@ void imapParser::parseQuotaRoot (parseString & result)
   lastResults.append( roots.join(" ") );
 }
 
+void imapParser::parseCustom (parseString & result)
+{
+  QByteArray word = parseLiteral (result, false, false);
+  lastResults.append( word );
+}
+
+void imapParser::parseOtherUser (parseString & result)
+{
+  lastResults.append( parseOneWord ( result ) );
+}
+
+void imapParser::parseDelegate (parseString & result)
+{
+  const QString email = parseOneWord ( result );
+
+  QStringList rights;
+  while ( !result.isEmpty() ) {
+    QByteArray word = parseLiteral ( result, false, false );
+    rights.append( word );
+  }
+
+  lastResults.append( email + ":" + rights.join( "," ) );
+}
+
+void imapParser::parseOutOfOffice (parseString & result)
+{
+  const QString state = parseOneWord (result);
+  parseOneWord (result); // skip encoding
+
+  QByteArray msg = parseLiteral (result, false, false);
+
+  lastResults.append( state + "^" + QString::fromUtf8( msg ) );
+}
+
 void imapParser::parseMyRights (parseString & result)
 {
   parseOneWord (result); // skip mailbox name
@@ -1838,8 +1891,7 @@ QByteArray imapParser::parseLiteral(parseString & inWords, bool relay, bool stop
     {
       bool proper;
       long runLenSave = runLen + 1;
-      QByteArray tmpstr;
-      tmpstr.resize(runLen);
+      QByteArray tmpstr(runLen, '\0');
       inWords.takeMidNoResize(tmpstr, 1, runLen - 1);
       runLen = tmpstr.toULong (&proper);
       inWords.pos += runLenSave;
@@ -1901,7 +1953,7 @@ QByteArray imapParser::parseOneWord (parseString & inWords, bool stopAtBracket)
       inWords.takeLeftNoResize(retVal, i - 1);
       len = i - 1;
       int offset = 0;
-      for (unsigned int j = 0; j <= len; j++) {
+      for (unsigned int j = 0; j < len; j++) {
         if (retVal[j] == '\\') {
           offset++;
           j++;
