@@ -26,7 +26,8 @@
 
 #include <kurl.h>
 
-#include "kldap.h"
+#include "ldapdn.h"
+#include "kldap_export.h"
 
 namespace KLDAP {
 
@@ -54,8 +55,10 @@ class KLDAP_EXPORT LdapUrl : public KUrl
 
     /** Constructs an empty KLdapUrl. */
     LdapUrl();
+
     /** Constructs a KLdapUrl from a KUrl. */
     explicit LdapUrl( const KUrl &url );
+
     /** Constructs a KLdapUrl from a LdapUrl. */
     LdapUrl( const LdapUrl &that );
 
@@ -67,39 +70,50 @@ class KLDAP_EXPORT LdapUrl : public KUrl
      * Returns the dn part of the LDAP Url (same as path(), but slash removed
      * from the beginning).
      */
-    QString dn() const;
+    LdapDN dn() const;
+
     /** Sets the the dn part of the LDAP Url. */
-    void setDn( const QString &dn );
+    void setDn( const LdapDN &dn );
 
     /** Returns the attributes part of the LDAP Url */
     QStringList attributes() const;
+
     /** Sets the attributes part of the LDAP Url */
     void setAttributes( const QStringList &attributes );
 
     /** Returns the scope part of the LDAP Url */
     Scope scope() const;
+
     /** Sets the scope part of the LDAP Url */
     void setScope( Scope scope );
 
     /** Returns the filter part of the LDAP Url */
     QString filter() const;
+
     /** Sets the filter part of the LDAP Url */
     void setFilter( const QString &filter );
 
     /** Returns if the specified extension exists in the LDAP Url */
     bool hasExtension( const QString &key ) const;
+
     /** Returns the specified extension */
     Extension extension( const QString &key ) const;
+
     /** Returns the specified extension */
     QString extension( const QString &key, bool &critical ) const;
+
     /** Sets the specified extension key with the value and criticality in ext */
     void setExtension( const QString &key, const Extension &ext );
+
     /** Sets the specified extension key with the value and criticality specified */
     void setExtension( const QString &key, const QString &value, bool critical = false );
+
     /** Sets the specified extension key with the value and criticality specified */
     void setExtension( const QString &key, int value, bool critical = false );
+
     /** Removes the specified extension */
     void removeExtension( const QString &key );
+
     /** Updates the query component from the attributes, scope, filter and extensions */
     void updateQuery();
 
