@@ -31,10 +31,10 @@
 #ifndef KTNEFMESSAGE_H
 #define KTNEFMESSAGE_H
 
-#include <QList>
+#include <QtCore/QList>
 
 #include "ktnefpropertyset.h"
-#include "ktnef.h"
+#include "ktnef_export.h"
 
 namespace KTnef { class KTNEFAttach; }
 
@@ -94,6 +94,8 @@ private:
   class MessagePrivate;
   MessagePrivate *const d;
   //@endcond
+
+  Q_DISABLE_COPY( KTNEFMessage )
 };
 
 }
