@@ -31,9 +31,9 @@
 #ifndef KTNEFPROPERTY_H
 #define KTNEFPROPERTY_H
 
-#include <QVariant>
-#include <QString>
-#include "ktnef.h"
+#include <QtCore/QVariant>
+#include <QtCore/QString>
+#include "ktnef_export.h"
 
 namespace KTnef {
 
@@ -84,6 +84,13 @@ public:
    */
   KTNEFProperty( const KTNEFProperty &p );
 
+  /**
+   * Destroys the property.
+   */
+  ~KTNEFProperty();
+
+  KTNEFProperty& operator=( const KTNEFProperty &other );
+
   /**
    * Returns the key string of the property.
    *
@@ -145,10 +152,8 @@ public:
 
 private:
   //@cond PRIVATE
-  int _key;
-  int _type;
-  QVariant _value;
-  QVariant _name;
+  class Private;
+  Private* const d;
   //@endcond
 };
 
