@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,9 +20,6 @@
  *
  */
 
-#include <documentvisitor.h>
-#include <tools.h>
-
 #include "document.h"
 #include "dublincore.h"
 #include "image.h"
@@ -35,8 +32,11 @@
 #include "syndicationinfo.h"
 #include "textinput.h"
 
-#include <QList>
-#include <QString>
+#include <documentvisitor.h>
+#include <tools.h>
+
+#include <QtCore/QList>
+#include <QtCore/QString>
 
 namespace Syndication {
 namespace RDF {
