@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,11 +22,11 @@
 #ifndef SYNDICATION_SPECIFICITEMVISITOR_H
 #define SYNDICATION_SPECIFICITEMVISITOR_H
 
-#include "ksyndication.h"
+#include "ksyndication_export.h"
 
 namespace Syndication {
 
-class SpecificDocument;
+class SpecificItem;
 
 namespace Atom
 {
