@@ -1,7 +1,7 @@
 /*
     This file is part of LibSyndication.
 
-    Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+    Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,9 +27,9 @@
 #include "feed.h"
 #include "parsercollection.h"
 
-#include <QByteArray>
-#include <QFile>
-#include <QString>
+#include <QtCore/QByteArray>
+#include <QtCore/QFile>
+#include <QtCore/QString>
 
 #include <iostream>
 
